# Doze-Detection
This is an application that automatically detects whether the user is falling asleep or not by checking if the user has signs of closing their eyes for more than a certain time threshold. This application can be useful when driving long distances or when needing to concentrate on work.
